@@ -19,15 +19,12 @@
  */
 
 #include "csync.h"
-#include "moc_csync.cpp"
 
 #include <QMetaEnum>
 
 QDebug operator<<(QDebug debug, const SyncInstructions &enumValue)
 {
-    static const QMetaObject *mo = qt_getEnumMetaObject(SyncInstruction());
-    static const int enumIdx = mo->indexOfEnumerator(qt_getEnumName(SyncInstruction()));
-    static const QMetaEnum me = mo->enumerator(enumIdx);
+    static const QMetaEnum me = QMetaEnum::fromType<SyncInstruction>();
     QDebugStateSaver saver(debug);
     debug.nospace().noquote() << me.enumName() << "(" << me.valueToKeys(enumValue) << ")";
     return debug;
