@@ -36,10 +36,10 @@ public:
     bool isComplete() const override;
 
 
-    QVariant selectedSpace(Spaces::SpacesModel::Columns column) const;
+    GraphApi::Space *currentSpace() const;
 
 private:
     Ui::SpacesPage *ui;
 };
 
-}
\ No newline at end of file
+}
