@@ -12,20 +12,11 @@
  * for more details.
  */
 
-#ifndef LOGBROWSER_H
-#define LOGBROWSER_H
+#pragma once
+
+#include "gui/owncloudguilib.h"
 
-#include <QCheckBox>
-#include <QPlainTextEdit>
-#include <QTextStream>
-#include <QFile>
-#include <QObject>
-#include <QList>
-#include <QDateTime>
 #include <QDialog>
-#include <QLineEdit>
-#include <QPushButton>
-#include <QLabel>
 
 namespace OCC {
 
@@ -37,7 +28,7 @@ namespace Ui {
  * @brief The LogBrowser class
  * @ingroup gui
  */
-class LogBrowser : public QDialog
+class OWNCLOUDGUI_EXPORT LogBrowser : public QDialog
 {
     Q_OBJECT
 public:
@@ -51,14 +42,11 @@ public:
      */
     static void setupLoggingFromConfig();
 
-protected slots:
+protected Q_SLOTS:
     void togglePermanentLogging(bool enabled);
-    void toggleLogDeletion(bool enabled);
 
 private:
     QScopedPointer<Ui::LogBrowser> ui;
 };
 
 } // namespace
-
-#endif // LOGBROWSER_H
