@@ -12,24 +12,18 @@
  * for more details.
  */
 
-#include <QtCore>
 #include <QAbstractListModel>
-#include <QWidget>
-#include <QIcon>
-#include <QJsonObject>
 #include <QJsonDocument>
+#include <QJsonObject>
+#include <QtCore>
 
-#include "accessmanager.h"
 #include "account.h"
 #include "accountmanager.h"
 #include "accountstate.h"
 #include "folderman.h"
-#include "guiutility.h"
 #include "models.h"
 #include "networkjobs/jsonjob.h"
 
-#include "resources/resources.h"
-
 #include "activitydata.h"
 #include "activitylistmodel.h"
 
@@ -56,7 +50,7 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
     }
 
     const auto &a = _finalList.at(index.row());
-    const AccountStatePtr accountState = AccountManager::instance()->account(a.accountUuid());
+    const AccountStatePtr accountState = AccountManager::instance()->accountState(a.accountUuid());
     if (!accountState) {
         return {};
     }
@@ -98,11 +92,7 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
     case Qt::DecorationRole:
         switch (column) {
         case ActivityRole::Text:
-            if (!accountState->account()->avatar().isNull()) {
-                return QIcon(accountState->account()->avatar());
-            } else {
-                return Resources::getCoreIcon(QStringLiteral("account"));
-            }
+            return accountState->account()->avatar();
         default:
             return {};
         }
@@ -210,7 +200,7 @@ void ActivityListModel::startFetchJob(AccountStatePtr ast)
              * to support this new behavior, we have to fake the expected status code
              */
             if (job->reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() != 200) {
-                emit activityJobStatusCode(ast, 999);
+                Q_EMIT activityJobStatusCode(ast, 999);
                 return;
             }
 
@@ -226,13 +216,13 @@ void ActivityListModel::startFetchJob(AccountStatePtr ast)
 
             _activityLists[ast] = std::move(list);
 
-            emit activityJobStatusCode(ast, job->ocsStatus());
+            Q_EMIT activityJobStatusCode(ast, job->ocsStatus());
 
             combineActivityLists();
         });
 
     _currentlyFetching.insert(ast, job);
-    qCInfo(lcActivity) << "Start fetching activities for " << ast->account()->displayName();
+    qCInfo(lcActivity) << "Start fetching activities for " << ast->account()->displayNameWithHost();
     job->start();
 }
 
@@ -240,7 +230,7 @@ void ActivityListModel::startFetchJob(AccountStatePtr ast)
 void ActivityListModel::combineActivityLists()
 {
     ActivityList resultList;
-    for (const ActivityList &list : qAsConst(_activityLists)) {
+    for (const ActivityList &list : std::as_const(_activityLists)) {
         resultList.append(list);
     }
     setActivityList(std::move(resultList));
