@@ -32,14 +32,15 @@ private Q_SLOTS:
 
         auto dir = TestUtils::createTempDir();
 
-        auto account = TestUtils::createDummyAccount();
+        auto newAccountState = TestUtils::createDummyAccount();
 
-        AccountStatePtr newAccountState = AccountState::fromNewAccount(account);
         const QDir d(dir.path());
-        QVERIFY(d.mkdir("foo"));
-        QVERIFY(d.mkdir("bar"));
-        auto foo = TestUtils::folderMan()->addFolder(newAccountState, TestUtils::createDummyFolderDefinition(newAccountState->account(), dir.path() + QStringLiteral("/foo")));
-        auto bar = TestUtils::folderMan()->addFolder(newAccountState, TestUtils::createDummyFolderDefinition(newAccountState->account(), dir.path() + QStringLiteral("/bar")));
+        QVERIFY(d.mkdir(QStringLiteral("foo")));
+        QVERIFY(d.mkdir(QStringLiteral("bar")));
+        auto foo = TestUtils::folderMan()->addFolder(
+            newAccountState.get(), TestUtils::createDummyFolderDefinition(newAccountState->account(), dir.path() + QStringLiteral("/foo")));
+        auto bar = TestUtils::folderMan()->addFolder(
+            newAccountState.get(), TestUtils::createDummyFolderDefinition(newAccountState->account(), dir.path() + QStringLiteral("/bar")));
 
         QVERIFY(foo);
         QVERIFY(bar);
