@@ -22,7 +22,7 @@ class TestBlacklist : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase_data()
     {
         QTest::addColumn<Vfs::Mode>("vfsMode");
@@ -36,7 +36,7 @@ private slots:
             // TODO: the hydrated version will fail due to an issue in the winvfs plugin, so leave it disabled for now.
             // QTest::newRow("Vfs::WindowsCfApi hydrated") << Vfs::WindowsCfApi << false;
         } else if (Utility::isWindows()) {
-            QWARN("Skipping Vfs::WindowsCfApi");
+            qWarning("Skipping Vfs::WindowsCfApi");
         }
     }
 
@@ -60,7 +60,7 @@ private slots:
         auto &modifier = remote ? fakeFolder.remoteModifier() : fakeFolder.localModifier();
 
         int counter = 0;
-        const QByteArray testFileName = QByteArrayLiteral("A/new");
+        const QString testFileName = QStringLiteral("A/new");
         QByteArray reqId;
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &req, QIODevice *) -> QNetworkReply * {
             if (req.url().path().endsWith(testFileName)) {
@@ -96,7 +96,7 @@ private slots:
             auto it = completeSpy.findItem(testFileName);
             QVERIFY(it);
             QCOMPARE(it->_status, SyncFileItem::NormalError); // initial error visible
-            QCOMPARE(it->_instruction, CSYNC_INSTRUCTION_NEW);
+            QCOMPARE(it->instruction(), CSYNC_INSTRUCTION_NEW);
 
             auto entry = fakeFolder.syncJournal().errorBlacklistEntry(testFileName);
             QVERIFY(entry.isValid());
@@ -118,7 +118,7 @@ private slots:
             auto it = completeSpy.findItem(testFileName);
             QVERIFY(it);
             QCOMPARE(it->_status, SyncFileItem::BlacklistedError);
-            QCOMPARE(it->_instruction, CSYNC_INSTRUCTION_IGNORE); // no retry happened!
+            QCOMPARE(it->instruction(), CSYNC_INSTRUCTION_IGNORE); // no retry happened!
 
             auto entry = fakeFolder.syncJournal().errorBlacklistEntry(testFileName);
             QVERIFY(entry.isValid());
@@ -145,7 +145,7 @@ private slots:
             auto it = completeSpy.findItem(testFileName);
             QVERIFY(it);
             QCOMPARE(it->_status, SyncFileItem::BlacklistedError); // blacklisted as it's just a retry
-            QCOMPARE(it->_instruction, CSYNC_INSTRUCTION_NEW); // retry!
+            QCOMPARE(it->instruction(), CSYNC_INSTRUCTION_NEW); // retry!
 
             auto entry = fakeFolder.syncJournal().errorBlacklistEntry(testFileName);
             QVERIFY(entry.isValid());
@@ -171,7 +171,7 @@ private slots:
             auto it = completeSpy.findItem(testFileName);
             QVERIFY(it);
             QCOMPARE(it->_status, SyncFileItem::BlacklistedError);
-            QCOMPARE(it->_instruction, CSYNC_INSTRUCTION_NEW); // retry!
+            QCOMPARE(it->instruction(), CSYNC_INSTRUCTION_NEW); // retry!
 
             auto entry = fakeFolder.syncJournal().errorBlacklistEntry(testFileName);
             QVERIFY(entry.isValid());
@@ -199,14 +199,14 @@ private slots:
             auto it = completeSpy.findItem(testFileName);
             QVERIFY(it);
             QCOMPARE(it->_status, SyncFileItem::Success);
-            QCOMPARE(it->_instruction, CSYNC_INSTRUCTION_NEW);
+            QCOMPARE(it->instruction(), CSYNC_INSTRUCTION_NEW);
 
             auto entry = fakeFolder.syncJournal().errorBlacklistEntry(testFileName);
             QVERIFY(!entry.isValid());
             QCOMPARE(counter, 4);
 
             if (remote)
-                QCOMPARE(journalRecord(fakeFolder, "A")._etag, fakeFolder.currentRemoteState().find("A")->etag);
+                QCOMPARE(journalRecord(fakeFolder, "A")._etag, fakeFolder.currentRemoteState().find(QStringLiteral("A"))->etag);
         }
         cleanup();
 
