@@ -19,7 +19,7 @@ using namespace OCC;
 bool itemDidComplete(const ItemCompletedSpy &spy, const QString &path)
 {
     if (auto item = spy.findItem(path)) {
-        return item->_instruction != CSYNC_INSTRUCTION_NONE && item->_instruction != CSYNC_INSTRUCTION_UPDATE_METADATA;
+        return item->instruction() & ~(CSYNC_INSTRUCTION_NONE | CSYNC_INSTRUCTION_UPDATE_METADATA);
     }
     return false;
 }
@@ -27,7 +27,7 @@ bool itemDidComplete(const ItemCompletedSpy &spy, const QString &path)
 bool itemInstruction(const ItemCompletedSpy &spy, const QString &path, const SyncInstructions instr)
 {
     auto item = spy.findItem(path);
-    return item->_instruction == instr;
+    return item->instruction() == instr;
 }
 
 bool itemDidCompleteSuccessfully(const ItemCompletedSpy &spy, const QString &path)
@@ -42,7 +42,7 @@ class TestSyncEngine : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase_data()
     {
         QTest::addColumn<Vfs::Mode>("vfsMode");
@@ -56,7 +56,7 @@ private slots:
             // TODO: the hydrated version will fail due to an issue in the winvfs plugin, so leave it disabled for now.
             // QTest::newRow("Vfs::WindowsCfApi hydrated") << Vfs::WindowsCfApi << false;
         } else if (Utility::isWindows()) {
-            QWARN("Skipping Vfs::WindowsCfApi");
+            qWarning("Skipping Vfs::WindowsCfApi");
         }
     }
 
@@ -69,7 +69,7 @@ private slots:
         fakeFolder.remoteModifier().insert(QStringLiteral("A/a0"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "A/a0"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("A/a0")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -82,7 +82,7 @@ private slots:
         fakeFolder.localModifier().insert(QStringLiteral("A/a0"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "A/a0"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("A/a0")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -97,9 +97,9 @@ private slots:
         fakeFolder.remoteModifier().insert(QStringLiteral("Z/d0"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Y"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Z"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Z/d0"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Y")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Z")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Z/d0")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -114,9 +114,9 @@ private slots:
         fakeFolder.localModifier().insert(QStringLiteral("Z/d0"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Y"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Z"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "Z/d0"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Y")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Z")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("Z/d0")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -129,7 +129,7 @@ private slots:
         fakeFolder.remoteModifier().remove(QStringLiteral("A/a1"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "A/a1"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("A/a1")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -142,7 +142,7 @@ private slots:
         fakeFolder.localModifier().remove(QStringLiteral("A/a1"));
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "A/a1"));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("A/a1")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -151,11 +151,11 @@ private slots:
         QFETCH_GLOBAL(bool, filesAreDehydrated);
 
         FakeFolder fakeFolder(FileInfo {}, vfsMode, filesAreDehydrated);
-        fakeFolder.account()->setCapabilities(TestUtils::testCapabilities(CheckSums::Algorithm::SHA1));
-        fakeFolder.localModifier().insert(QStringLiteral("a1.eml"), 64_b, 'A');
-        fakeFolder.localModifier().insert(QStringLiteral("a2.eml"), 64_b, 'A');
-        fakeFolder.localModifier().insert(QStringLiteral("a3.eml"), 64_b, 'A');
-        fakeFolder.localModifier().insert(QStringLiteral("b3.txt"), 64_b, 'A');
+        fakeFolder.account()->setCapabilities({fakeFolder.account()->url(), TestUtils::testCapabilities(CheckSums::Algorithm::SHA1)});
+        fakeFolder.localModifier().insert(QStringLiteral("a1.eml"), 64_B, 'A');
+        fakeFolder.localModifier().insert(QStringLiteral("a2.eml"), 64_B, 'A');
+        fakeFolder.localModifier().insert(QStringLiteral("a3.eml"), 64_B, 'A');
+        fakeFolder.localModifier().insert(QStringLiteral("b3.txt"), 64_B, 'A');
         // Upload and calculate the checksums
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
@@ -167,35 +167,36 @@ private slots:
 
         // printf 'A%.0s' {1..64} | sha1sum -
         QByteArray referenceChecksum("SHA1:30b86e44e6001403827a62c58b08893e77cf121f");
-        QCOMPARE(getDbChecksum("a1.eml"), referenceChecksum);
-        QCOMPARE(getDbChecksum("a2.eml"), referenceChecksum);
-        QCOMPARE(getDbChecksum("a3.eml"), referenceChecksum);
-        QCOMPARE(getDbChecksum("b3.txt"), referenceChecksum);
+        QCOMPARE(getDbChecksum(QStringLiteral("a1.eml")), referenceChecksum);
+        QCOMPARE(getDbChecksum(QStringLiteral("a2.eml")), referenceChecksum);
+        QCOMPARE(getDbChecksum(QStringLiteral("a3.eml")), referenceChecksum);
+        QCOMPARE(getDbChecksum(QStringLiteral("b3.txt")), referenceChecksum);
 
         // Make sure that the lastModified time caused by the setContent calls below is actually different:
         QThread::sleep(1);
 
         ItemCompletedSpy completeSpy(fakeFolder);
         // Touch the file without changing the content, shouldn't upload
-        fakeFolder.localModifier().setContents(QStringLiteral("a1.eml"), 64_b, 'A');
+        fakeFolder.localModifier().setContents(QStringLiteral("a1.eml"), 64_B, 'A');
         // Change the content/size
-        fakeFolder.localModifier().setContents(QStringLiteral("a2.eml"), 64_b, 'B');
+        fakeFolder.localModifier().setContents(QStringLiteral("a2.eml"), 64_B, 'B');
         fakeFolder.localModifier().appendByte(QStringLiteral("a3.eml"), 'X');
         fakeFolder.localModifier().appendByte(QStringLiteral("b3.txt"), 'X');
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
-        QCOMPARE(getDbChecksum("a1.eml"), referenceChecksum);
-        QCOMPARE(getDbChecksum("a2.eml"), QByteArray("SHA1:84951fc23a4dafd10020ac349da1f5530fa65949"));
-        QCOMPARE(getDbChecksum("a3.eml"), QByteArray("SHA1:c119308d57884896cd86a7050e449aaba24b1fee"));
-        QCOMPARE(getDbChecksum("b3.eml"), getDbChecksum("a3.txt"));
+        QCOMPARE(getDbChecksum(QStringLiteral("a1.eml")), referenceChecksum);
+        QCOMPARE(getDbChecksum(QStringLiteral("a2.eml")), QByteArray("SHA1:84951fc23a4dafd10020ac349da1f5530fa65949"));
+        QCOMPARE(getDbChecksum(QStringLiteral("a3.eml")), QByteArray("SHA1:c119308d57884896cd86a7050e449aaba24b1fee"));
+        QCOMPARE(getDbChecksum(QStringLiteral("b3.eml")), getDbChecksum(QStringLiteral("a3.txt")));
 
-        QVERIFY(!itemDidComplete(completeSpy, "a1.eml"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "a2.eml"));
-        QVERIFY(itemDidCompleteSuccessfully(completeSpy, "a3.eml"));
+        QVERIFY(!itemDidComplete(completeSpy, QStringLiteral("a1.eml")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("a2.eml")));
+        QVERIFY(itemDidCompleteSuccessfully(completeSpy, QStringLiteral("a3.eml")));
 
         // The local and remote state now differ: the local mtime for `a1.eml` is bigger (newer) than on the server, because
         // the upload was skipped (same checksum). So first verify that this is the case:
-        QVERIFY(fakeFolder.currentLocalState().find("a1.eml")->lastModified() > fakeFolder.currentRemoteState().find("a1.eml")->lastModified());
+        QVERIFY(fakeFolder.currentLocalState().find(QStringLiteral("a1.eml"))->lastModified()
+            > fakeFolder.currentRemoteState().find(QStringLiteral("a1.eml"))->lastModified());
         // And then check if everything else actually is the same:
         QVERIFY(fakeFolder.currentLocalState().equals(fakeFolder.currentRemoteState(), FileInfo::IgnoreLastModified));
     }
@@ -216,8 +217,7 @@ private slots:
         auto expectedServerState = fakeFolder.currentRemoteState();
 
         // Remove subFolderA with selectiveSync:
-        fakeFolder.syncEngine().journal()->setSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList,
-                                                                {"parentFolder/subFolderA/"});
+        fakeFolder.syncEngine().journal()->setSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, {QStringLiteral("parentFolder/subFolderA/")});
         fakeFolder.syncEngine().journal()->schedulePathForRemoteDiscovery(QByteArrayLiteral("parentFolder/subFolderA/"));
         auto getEtag = [&](const QByteArray &file) {
             SyncJournalFileRecord rec;
@@ -246,15 +246,15 @@ private slots:
                 QCOMPARE(fakeFolder.currentRemoteState(), expectedServerState);
                 // The local state should still have subFolderA
                 auto local = fakeFolder.currentLocalState();
-                QVERIFY(local.find("parentFolder/subFolderA"));
-                QVERIFY(!local.find("parentFolder/subFolderA/fileA.txt"));
-                QVERIFY(local.find("parentFolder/subFolderA/fileB.txt"));
-                QVERIFY(!local.find("parentFolder/subFolderA/subsubFolder/fileC.txt"));
-                QVERIFY(local.find("parentFolder/subFolderA/subsubFolder/fileD.txt"));
-                QVERIFY(!local.find("parentFolder/subFolderA/anotherFolder/subsubFolder/fileE.txt"));
-                QVERIFY(local.find("parentFolder/subFolderA/anotherFolder/subsubFolder/fileF.txt"));
-                QVERIFY(!local.find("parentFolder/subFolderA/anotherFolder/emptyFolder"));
-                QVERIFY(local.find("parentFolder/subFolderB"));
+                QVERIFY(local.find(QStringLiteral("parentFolder/subFolderA")));
+                QVERIFY(!local.find(QStringLiteral("parentFolder/subFolderA/fileA.txt")));
+                QVERIFY(local.find(QStringLiteral("parentFolder/subFolderA/fileB.txt")));
+                QVERIFY(!local.find(QStringLiteral("parentFolder/subFolderA/subsubFolder/fileC.txt")));
+                QVERIFY(local.find(QStringLiteral("parentFolder/subFolderA/subsubFolder/fileD.txt")));
+                QVERIFY(!local.find(QStringLiteral("parentFolder/subFolderA/anotherFolder/subsubFolder/fileE.txt")));
+                QVERIFY(local.find(QStringLiteral("parentFolder/subFolderA/anotherFolder/subsubFolder/fileF.txt")));
+                QVERIFY(!local.find(QStringLiteral("parentFolder/subFolderA/anotherFolder/emptyFolder")));
+                QVERIFY(local.find(QStringLiteral("parentFolder/subFolderB")));
             }
         }
     }
@@ -421,7 +421,7 @@ private slots:
         auto mtime = QDateTime::currentDateTimeUtc().addDays(-4);
         mtime.setMSecsSinceEpoch(mtime.toMSecsSinceEpoch() / 1000 * 1000);
 
-        const auto a1size = fakeFolder.currentRemoteState().find("A/a1")->contentSize;
+        const auto a1size = fakeFolder.currentRemoteState().find(QStringLiteral("A/a1"))->contentSize;
 
         // In the dehydrated case, executing this `setContents` will cause a hydration of the file, so there will always be 1 GET request.
         fakeFolder.localModifier().setContents(QStringLiteral("A/a1"), a1size, 'C');
@@ -432,12 +432,12 @@ private slots:
             mtime = mtime.addDays(1);
         }
         fakeFolder.remoteModifier().setModTime(QStringLiteral("A/a1"), mtime);
-        remoteInfo.find("A/a1")->checksums = checksums;
+        remoteInfo.find(QStringLiteral("A/a1"))->checksums = checksums;
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(counter.nGET, expectedGET);
 
         // check that mtime in journal and filesystem agree
-        QString a1path = fakeFolder.localPath() + "A/a1";
+        QString a1path = fakeFolder.localPath() + QStringLiteral("A/a1");
         SyncJournalFileRecord a1record;
         fakeFolder.syncJournal().getFileRecord(QByteArray("A/a1"), &a1record);
         QCOMPARE(a1record._modtime, (qint64)FileSystem::getModTime(a1path));
@@ -503,7 +503,7 @@ private slots:
 
             // a1: should have local size and modtime
             QVERIFY(a1);
-            QCOMPARE(a1->_instruction, CSYNC_INSTRUCTION_SYNC);
+            QCOMPARE(a1->instruction(), CSYNC_INSTRUCTION_SYNC);
             QCOMPARE(a1->_direction, SyncFileItem::Up);
             QCOMPARE(a1->_size, qint64(5));
 
@@ -513,7 +513,7 @@ private slots:
 
             // b2: should have remote size and modtime
             QVERIFY(b1);
-            QCOMPARE(b1->_instruction, CSYNC_INSTRUCTION_SYNC);
+            QCOMPARE(b1->instruction(), CSYNC_INSTRUCTION_SYNC);
             QCOMPARE(b1->_direction, SyncFileItem::Down);
             QCOMPARE(b1->_size, qint64(17));
             QCOMPARE(Utility::qDateTimeFromTime_t(b1->_modtime), changedMtime);
@@ -522,7 +522,7 @@ private slots:
 
             // c1: conflicts are downloads, so remote size and modtime
             QVERIFY(c1);
-            QCOMPARE(c1->_instruction, CSYNC_INSTRUCTION_CONFLICT);
+            QCOMPARE(c1->instruction(), CSYNC_INSTRUCTION_CONFLICT);
             QCOMPARE(c1->_direction, SyncFileItem::None);
             QCOMPARE(c1->_size, qint64(25));
             QCOMPARE(Utility::qDateTimeFromTime_t(c1->_modtime), changedMtime2);
@@ -563,22 +563,22 @@ private slots:
             return nullptr;
         });
 
-        fakeFolder.localModifier().insert(QStringLiteral("A/big"), 800_b);
+        fakeFolder.localModifier().insert(QStringLiteral("A/big"), 800_B);
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nPUT, 1);
         QCOMPARE(n507, 0);
 
         nPUT = 0;
-        fakeFolder.localModifier().insert(QStringLiteral("A/big1"), 500_b); // ok
-        fakeFolder.localModifier().insert(QStringLiteral("A/big2"), 1200_b); // 507 (quota guess now 1199)
-        fakeFolder.localModifier().insert(QStringLiteral("A/big3"), 1200_b); // skipped
-        fakeFolder.localModifier().insert(QStringLiteral("A/big4"), 1500_b); // skipped
-        fakeFolder.localModifier().insert(QStringLiteral("A/big5"), 1100_b); // 507 (quota guess now 1099)
-        fakeFolder.localModifier().insert(QStringLiteral("A/big6"), 900_b); // ok (quota guess now 199)
-        fakeFolder.localModifier().insert(QStringLiteral("A/big7"), 200_b); // skipped
-        fakeFolder.localModifier().insert(QStringLiteral("A/big8"), 199_b); // ok (quota guess now 0)
+        fakeFolder.localModifier().insert(QStringLiteral("A/big1"), 500_B); // ok
+        fakeFolder.localModifier().insert(QStringLiteral("A/big2"), 1200_B); // 507 (quota guess now 1199)
+        fakeFolder.localModifier().insert(QStringLiteral("A/big3"), 1200_B); // skipped
+        fakeFolder.localModifier().insert(QStringLiteral("A/big4"), 1500_B); // skipped
+        fakeFolder.localModifier().insert(QStringLiteral("A/big5"), 1100_B); // 507 (quota guess now 1099)
+        fakeFolder.localModifier().insert(QStringLiteral("A/big6"), 900_B); // ok (quota guess now 199)
+        fakeFolder.localModifier().insert(QStringLiteral("A/big7"), 200_B); // skipped
+        fakeFolder.localModifier().insert(QStringLiteral("A/big8"), 199_B); // ok (quota guess now 0)
 
-        fakeFolder.localModifier().insert(QStringLiteral("B/big8"), 1150_b); // 507
+        fakeFolder.localModifier().insert(QStringLiteral("B/big8"), 1150_B); // 507
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nPUT, 6);
         QCOMPARE(n507, 3);
@@ -709,14 +709,14 @@ private slots:
         auto invalidFilenameRegexCapabilities = [](const QString &regex) {
             auto cap = TestUtils::testCapabilities();
             auto dav = cap[QStringLiteral("dav")].toMap();
-            dav.insert({ { "invalidFilenameRegex", regex } });
+            dav.insert({{QStringLiteral("invalidFilenameRegex"), regex}});
             cap[QStringLiteral("dav")] = dav;
             return cap;
         };
-        fakeFolder.syncEngine().account()->setCapabilities(invalidFilenameRegexCapabilities(QStringLiteral("my[fgh]ile")));
+        fakeFolder.syncEngine().account()->setCapabilities({fakeFolder.account()->url(), invalidFilenameRegexCapabilities(QStringLiteral("my[fgh]ile"))});
         fakeFolder.localModifier().insert(QStringLiteral("C/myfile.txt"));
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(!fakeFolder.currentRemoteState().find("C/myfile.txt"));
+        QVERIFY(!fakeFolder.currentRemoteState().find(QStringLiteral("C/myfile.txt")));
     }
 
     void testDiscoveryHiddenFile()
@@ -738,80 +738,14 @@ private slots:
         fakeFolder.remoteModifier().insert(QStringLiteral("A/.hidden"));
         fakeFolder.localModifier().insert(QStringLiteral("B/.hidden"));
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(!localFileExists("A/.hidden"));
-        QVERIFY(!fakeFolder.currentRemoteState().find("B/.hidden"));
+        QVERIFY(!localFileExists(QStringLiteral("A/.hidden")));
+        QVERIFY(!fakeFolder.currentRemoteState().find(QStringLiteral("B/.hidden")));
 
         fakeFolder.syncEngine().setIgnoreHiddenFiles(false);
         fakeFolder.syncJournal().forceRemoteDiscoveryNextSync();
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(localFileExists("A/.hidden"));
-        QVERIFY(fakeFolder.currentRemoteState().find("B/.hidden"));
-    }
-
-    void testNoLocalEncoding()
-    {
-        const auto utf8Locale = QTextCodec::codecForLocale();
-        if (!Utility::isWindows()) {
-            if (utf8Locale->mibEnum() != 106) {
-                QSKIP(qUtf8Printable(QStringLiteral("Test only works for UTF8 locale, but current locale is %1").arg(QString::fromUtf8(utf8Locale->name()))));
-            }
-        }
-
-        QFETCH_GLOBAL(Vfs::Mode, vfsMode);
-        QFETCH_GLOBAL(bool, filesAreDehydrated);
-
-        FakeFolder fakeFolder(FileInfo::A12_B12_C12_S12(), vfsMode, filesAreDehydrated);
-        QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-
-        // Utf8 locale can sync both
-        fakeFolder.remoteModifier().insert(QStringLiteral("A/tößt"));
-        fakeFolder.remoteModifier().insert(QStringLiteral("A/t𠜎t"));
-        fakeFolder.remoteModifier().insert(QStringLiteral("A/💩"));
-        QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(fakeFolder.currentLocalState().find("A/tößt"));
-        QVERIFY(fakeFolder.currentLocalState().find("A/t𠜎t"));
-        QVERIFY(fakeFolder.currentLocalState().find("A/💩"));
-
-#if !defined(Q_OS_MAC) && !defined(Q_OS_WIN)
-        // Try again with a locale that can represent ö but not 𠜎 (4-byte utf8).
-        auto codec = QTextCodec::codecForName("ISO-8859-15");
-        QVERIFY(codec);
-        QTextCodec::setCodecForLocale(codec);
-        QCOMPARE(QTextCodec::codecForLocale()->mibEnum(), 111);
-
-        fakeFolder.remoteModifier().insert(QStringLiteral("B/tößt"));
-        fakeFolder.remoteModifier().insert(QStringLiteral("B/t𠜎t"));
-        QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(fakeFolder.currentLocalState().find("B/tößt"));
-        QVERIFY(!fakeFolder.currentLocalState().find("B/t𠜎t"));
-        QVERIFY(!fakeFolder.currentLocalState().find("B/t?t"));
-        QVERIFY(!fakeFolder.currentLocalState().find("B/t??t"));
-        QVERIFY(!fakeFolder.currentLocalState().find("B/t???t"));
-        QVERIFY(!fakeFolder.currentLocalState().find("B/t????t"));
-        QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-        QVERIFY(fakeFolder.currentRemoteState().find("B/tößt"));
-        QVERIFY(fakeFolder.currentRemoteState().find("B/t𠜎t"));
-
-        // Try again with plain ascii
-        codec = QTextCodec::codecForName("ASCII");
-        if (codec) {
-            QTextCodec::setCodecForLocale(codec);
-            QCOMPARE(QTextCodec::codecForLocale()->mibEnum(), 3);
-
-            fakeFolder.remoteModifier().insert(QStringLiteral("C/tößt"));
-            QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-            QVERIFY(!fakeFolder.currentLocalState().find("C/tößt"));
-            QVERIFY(!fakeFolder.currentLocalState().find("C/t??t"));
-            QVERIFY(!fakeFolder.currentLocalState().find("C/t????t"));
-            QVERIFY(fakeFolder.applyLocalModificationsAndSync());
-            QVERIFY(fakeFolder.currentRemoteState().find("C/tößt"));
-        } else {
-            qDebug() << "Skipping test for ASCII, ASCII is not available, available encodings are:" << QTextCodec::availableCodecs();
-        }
-
-        QTextCodec::setCodecForLocale(utf8Locale);
-#endif
+        QVERIFY(localFileExists(QStringLiteral("A/.hidden")));
+        QVERIFY(fakeFolder.currentRemoteState().find(QStringLiteral("B/.hidden")));
     }
 
     // Aborting has had bugs when there are parallel upload jobs
@@ -829,23 +763,26 @@ private slots:
         auto cap = TestUtils::testCapabilities();
         // unset chunking v1
         cap.remove(QStringLiteral("dav"));
-        fakeFolder.account()->setCapabilities(cap);
+        fakeFolder.account()->setCapabilities({fakeFolder.account()->url(), cap});
 
-        QObject parent;
-        int nPUT = 0;
-        fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *) -> QNetworkReply * {
+        auto counter = std::make_unique<OperationCounter>();
+        fakeFolder.setServerOverride([counter = counter.get(), fakeFolder = &fakeFolder](
+                                         QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *device) -> QNetworkReply * {
+            counter->serverOverride(op, request, device);
             if (op == QNetworkAccessManager::PutOperation) {
-                ++nPUT;
-                return new FakeHangingReply(op, request, &parent);
+                return new FakeHangingReply(op, request, fakeFolder);
             }
             return nullptr;
         });
 
-        fakeFolder.localModifier().insert(QStringLiteral("file"), 100_b, 'W');
-        QTimer::singleShot(400ms, &fakeFolder.syncEngine(), [&]() { fakeFolder.syncEngine().abort(); });
+        fakeFolder.localModifier().insert(QStringLiteral("file"), 1_MiB, 'W');
+        // wait until the sync engine is ready
+        // wait a second and abort
+        connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToPropagate, &fakeFolder.syncEngine(),
+            [&]() { QTimer::singleShot(1s, &fakeFolder.syncEngine(), [&]() { fakeFolder.syncEngine().abort({}); }); });
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync());
 
-        QCOMPARE(nPUT, 3);
+        QCOMPARE(counter->nPUT, 3);
     }
 
 #ifndef Q_OS_WIN
@@ -856,19 +793,19 @@ private slots:
 
         FakeFolder fakeFolder(FileInfo::A12_B12_C12_S12(), vfsMode, filesAreDehydrated);
         auto perm = QFileDevice::Permission(0x7704); // user/owner: rwx, group: r, other: -
-        QFile::setPermissions(fakeFolder.localPath() + "A/a1", perm);
-        QFile::setPermissions(fakeFolder.localPath() + "A/a2", perm);
+        QFile::setPermissions(fakeFolder.localPath() + QStringLiteral("A/a1"), perm);
+        QFile::setPermissions(fakeFolder.localPath() + QStringLiteral("A/a2"), perm);
         fakeFolder.applyLocalModificationsAndSync(); // get the metadata-only change out of the way
         fakeFolder.remoteModifier().appendByte(QStringLiteral("A/a1"));
         fakeFolder.remoteModifier().appendByte(QStringLiteral("A/a2"));
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a2"));
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a2"));
         fakeFolder.applyLocalModificationsAndSync(); // perms should be preserved
-        QCOMPARE(QFileInfo(fakeFolder.localPath() + "A/a1").permissions(), perm);
-        QCOMPARE(QFileInfo(fakeFolder.localPath() + "A/a2").permissions(), perm);
+        QCOMPARE(QFileInfo(fakeFolder.localPath() + QStringLiteral("A/a1")).permissions(), perm);
+        QCOMPARE(QFileInfo(fakeFolder.localPath() + QStringLiteral("A/a2")).permissions(), perm);
 
-        auto conflictName = fakeFolder.syncJournal().conflictRecord(fakeFolder.syncJournal().conflictRecordPaths().first()).path;
-        QVERIFY(conflictName.contains("A/a2"));
+        const QString conflictName = QString::fromUtf8(fakeFolder.syncJournal().conflictRecord(fakeFolder.syncJournal().conflictRecordPaths().first()).path);
+        QVERIFY(conflictName.contains(QStringLiteral("A/a2")));
         QCOMPARE(QFileInfo(fakeFolder.localPath() + conflictName).permissions(), perm);
     }
 #endif
@@ -884,8 +821,7 @@ private slots:
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
-        QVERIFY(fakeFolder.currentLocalState().find("foo"));
-
+        QVERIFY(fakeFolder.currentLocalState().find(QStringLiteral("foo")));
     }
 
     // Check that server mtime is set on directories on initial propagation
@@ -899,12 +835,12 @@ private slots:
         fakeFolder.remoteModifier().insert(QStringLiteral("foo/bar"));
         auto datetime = QDateTime::currentDateTime();
         datetime.setSecsSinceEpoch(datetime.toSecsSinceEpoch()); // wipe ms
-        fakeFolder.remoteModifier().find("foo")->setLastModified(datetime);
+        fakeFolder.remoteModifier().find(QStringLiteral("foo"))->setLastModified(datetime);
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
-        QCOMPARE(QFileInfo(fakeFolder.localPath() + "foo").lastModified(), datetime);
+        QCOMPARE(QFileInfo(fakeFolder.localPath() + QStringLiteral("foo")).lastModified(), datetime);
     }
 
 
